{% load i18n pragmatic_tags %}

{% if filter_values|length > 0 %}
    <div class="filter-values">
        <strong>{% trans 'Filter values' %}:</strong>

        {% for param, field in filter_values.items %}
            <label>{{ field.label }}:</label>
            <span>
                {{ field.value }}
                <a href="{{ request.get_full_path|remove_query_param:param }}">{% trans 'Unset' %}</a>
            </span>
        {% endfor %}
    </div>
{% endif %}